@@ -33,6 +33,9 @@
 age_shiny <- function(age_list, features, quantile_type, use_plotly = TRUE){
   quantile_type <- quantile_type
   plotly_package <- requireNamespace("plotly", quietly = TRUE)
+  if (use_plotly && !plotly_package) {
+    warning("The `plotly` package is not available. Falling back to ggplot output.")
+  }
   use_plotly <- use_plotly && plotly_package
   ui <- function(request) {
     fluidPage(
@@ -223,10 +226,12 @@ age_shiny <- function(age_list, features, quantile_type, use_plotly = TRUE){
 
 #' Age Trend Estimates Generation
 #'
-#' A GAMLSS model using a Box-Cox t distribution was fitted separately to rois of interest,
-#' to establish normative reference ranges as a function of age for the volume of a specific roi.
+#' A GAMLSS model using a Normal distribution was fitted separately to rois of interest,
+#' to establish normative reference ranges for the volume of a specific ROI as a function of age,
+#' adjusting for sex and intracranial volume.
 #'
-#' @param sub_df A two-column dataset that contains age and roi volume related information. column y: roi volumes, column age: age.
+#' @param sub_df A four-column dataset that contains age, sex, intracranial volume (ICV) and roi volume related information.
+#' The columns for age, sex, and ICV must be strictly named `"age"`, `"sex"`, and `"icv"`.
 #' @param lq The lower bound quantile. eg: 0.25, 0.05
 #' @param hq The upper bound quantile. eg: 0.75, 0.95
 #' @param mu An indicator of whether to smooth age variable, include it as a linear term or only include the intercept in the mu formula.
